@@ -86,7 +86,7 @@
 #define KAUTHCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KAUTHCORE_NO_DEPRECATED
-#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KAUTHCORE_NO_DEPRECATED_WARNINGS
 #  define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define KAUTHCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KAUTHCORE_NO_DEPRECATED
-#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KAUTHCORE_NO_DEPRECATED_WARNINGS
 #  define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
