@@ -86,7 +86,7 @@
 #define KAUTH_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KAUTH_NO_DEPRECATED
-#  define KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KAUTH_NO_DEPRECATED_WARNINGS
 #  define KAUTH_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KAUTH_DEPRECATED_WARNINGS_SINCE KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KAUTH_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KAUTH_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define KAUTH_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KAUTH_NO_DEPRECATED
-#  define KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KAUTH_NO_DEPRECATED_WARNINGS
 #  define KAUTH_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KAUTH_DEPRECATED_WARNINGS_SINCE KAUTH_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KAUTH_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KAUTH_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
